DownloadProcess class

@author : fada @email : fada@mofada.cn @date : 2021/4/26 15:31 @description : input your description

Constructors

DownloadProcess({required int current, required int count, required ProcessState status})

Properties

count ↔ int
getter/setter pair
current ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ ProcessState
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map json) → DownloadProcess